@@ -1,7 +1,8 @@
 /* 
    Project: FisicaLab
 
-   Copyright (C) 2009, 2010, 2011, 2012, 2013 Free Software Foundation
+   Copyright (C) 2009, 2010, 2011, 2012, 2013,
+                 2014, 2015  Free Software Foundation
 
    Author: German A. Arias <germanandre@gmx.es>
 
@@ -34,6 +35,7 @@
   if ((self = [super init]))
     {
       preferencesPanel = nil;
+      propertiesWindow = nil;
     }
   return self;
 }
@@ -66,13 +68,27 @@
   dynamicsCircularView = [[NSScrollView alloc] initWithFrame:
 						 NSMakeRect(0, 0, 270, 320)];
   [dynamicsCircularView setHasVerticalScroller: YES];
-  [dynamicsCircularView setDocumentView: [dynamicsCircularParticles contentView]]; 
+  [dynamicsCircularView setDocumentView:
+			  [dynamicsCircularParticles contentView]]; 
   [dynamicsCircularParticlesView addSubview: dynamicsCircularView];
 
-  RELEASE(staticView);
-  RELEASE(staticRigidBodies);
-  RELEASE(dynamicsCircularView);
-  RELEASE(dynamicsCircularParticles);
+
+  [staticView release];
+  [staticRigidBodies release];
+  [dynamicsCircularView release];
+  [dynamicsCircularParticles release];
+}
+
+- (void) applicationDidFinishLaunching: (NSNotification*)aNotification
+{
+  NSUserDefaults *defaults = [NSUserDefaults standardUserDefaults];
+
+  if (![defaults boolForKey: @"HasStartedBefore"])
+    {
+      [NSBundle loadNibNamed: @"firstLaunchPanel" owner: self];
+      [firstLaunchPanel center];
+      [firstLaunchPanel makeKeyAndOrderFront: self];
+    }
 }
 
 - (void) showPrefPanel: (id)sender
@@ -131,6 +147,19 @@
     }
 }
 
+- (void) showPropertiesWindow: (id)sender
+{
+  if (propertiesWindow == nil)
+    {
+      [NSBundle loadNibNamed: @"properties.gorm" owner: self];
+      [propertiesWindow makeKeyAndOrderFront: self];
+    }
+  else
+    {
+      [propertiesWindow makeKeyAndOrderFront: self];
+    }
+}
+
 - (void) selectModule: (id)sender
 {
   // Cancel any operation add/move element.
@@ -217,4 +246,11 @@
   [fontsizeStepper setIntValue: 10];
 }
 
+// First launch panel
+- (void) notShowAgain: (id)sender
+{
+  NSUserDefaults *defaults = [NSUserDefaults standardUserDefaults];
+  [defaults setBool: YES forKey: @"HasStartedBefore"];
+}
+
 @end
