@@ -1,5 +1,5 @@
 /* 
-   Copyright (C) 2010, 2011, 2012, 2013 German A. Arias
+   Copyright (C) 2010, 2011, 2012, 2013, 2014 German A. Arias
 
    This file is part of FísicaLab application
 
@@ -26,19 +26,6 @@
 #import <gsl/gsl_rng.h>
 #import "FLCalorimetry.h"
 
-static BOOL messageTemp, changeOrCal;
-static int varT;
-static double timeData;
-static NSMutableDictionary *dictionary;
-static NSMutableArray *vars, *codeContainedObjects, *codeOthers,
-  *systemsApplied, *systemsType;
-static NSString *timeVar;
-
-struct parameters
-{
-  double a;
-  double b;
-};
 
 static int buildSystem (const gsl_vector *v, void *p, gsl_vector *func)
 {
@@ -50,6 +37,21 @@ static int buildSystem (const gsl_vector *v, void *p, gsl_vector *func)
   // Objects contained in codeOthers
   NSEnumerator *enumOthers;
 
+  // Get properties of FL object.
+  FLCalorimetry *FLObj = (__bridge FLCalorimetry *)(p);
+
+  BOOL messageTemp = FLObj->messageTemp;
+  BOOL changeOrCal = FLObj->changeOrCal;
+  NSInteger varT = FLObj->varT;
+  NSString *timeVar = FLObj->timeVar;
+  double timeData = FLObj->timeData;
+  NSMutableArray *vars = FLObj->vars;
+  NSMutableArray *codeContainedObjects = FLObj->codeContainedObjects;
+  NSMutableArray *codeOthers = FLObj->codeOthers;
+  NSMutableArray *systemsApplied = FLObj->systemsApplied;
+  NSMutableArray *systemsType = FLObj->systemsType;
+  NSMutableDictionary *dictionary = FLObj->dictionary;
+  // ----------------------------------------
   
   if (varT == 1)
     {
@@ -1403,8 +1405,6 @@ static int buildSystem (const gsl_vector *v, void *p, gsl_vector *func)
   NSString *message;
   size_t iter;
   
-  struct parameters p = {1.0, 1.0};
-  
   gsl_vector *x = gsl_vector_alloc (n);
   int Tindex;
   int countRes = 0;
@@ -1421,7 +1421,7 @@ static int buildSystem (const gsl_vector *v, void *p, gsl_vector *func)
   
   do
     {
-      gsl_multiroot_function f = {&buildSystem, n, &p};
+      gsl_multiroot_function f = {&buildSystem, n, (__bridge void *)(self)};
       iter = 0;
       for (k = 0; k < nvar; k++)
 	{
@@ -1517,16 +1517,12 @@ static int buildSystem (const gsl_vector *v, void *p, gsl_vector *func)
   NSBundle *messages;
   self = [super init];
   
-  vars = [NSMutableArray array];
-  [vars retain];
-  codeContainedObjects = [NSMutableArray array];
-  [codeContainedObjects retain];
-  codeOthers = [NSMutableArray array];
-  [codeOthers retain];
-  systemsApplied = [NSMutableArray array];
-  [systemsApplied retain];
-  systemsType = [NSMutableArray array];
-  [systemsType retain];
+  vars = [NSMutableArray new];
+  codeContainedObjects = [NSMutableArray new];
+  codeOthers = [NSMutableArray new];
+  systemsApplied = [NSMutableArray new];
+  systemsType = [NSMutableArray new];
+  dictionary = [NSMutableDictionary new];
   
   // Build the array of messages
   messages = [NSBundle mainBundle];
@@ -1569,7 +1565,7 @@ static int buildSystem (const gsl_vector *v, void *p, gsl_vector *func)
   height = [self chalkboardHeight];
   totalCells = width*height - 1;
 
-  dictionary = [[NSMutableDictionary alloc] initWithDictionary: list];
+  [dictionary setDictionary: list];
   keys = [[NSArray alloc] initWithArray: [list allKeys]];
   count = [keys objectEnumerator];
   
