@@ -1,5 +1,5 @@
 /* 
-   Copyright (C) 2009, 2010, 2011, 2012, 2013 German A. Arias
+   Copyright (C) 2009, 2010, 2011, 2012, 2013, 2014 German A. Arias
 
    This file is part of FísicaLab application
 
@@ -26,17 +26,6 @@
 #import <gsl/gsl_rng.h>
 #import "FLKinematics.h"
 
-static int varT;
-static double timeDat;
-static NSArray *dictionary;
-static NSMutableArray *vars, *varsTime;
-static NSString *timeVar;
-
-struct parameters
-{
-  double a;
-  double b;
-};
 
 static int buildSystem (const gsl_vector *v, void *p, gsl_vector *func)
 {
@@ -47,6 +36,16 @@ static int buildSystem (const gsl_vector *v, void *p, gsl_vector *func)
   NSEnumerator *enumerator;
   NSNumber *type;
   NSMutableArray *dat;
+
+  // Get properties of FL object.
+  FLKinematics *FLObj = (__bridge FLKinematics *)(p);
+
+  NSInteger varT = FLObj->varT;
+  NSString *timeVar = FLObj->timeVar;
+  double timeDat = FLObj->timeDat;
+  NSMutableArray *vars = FLObj->vars;
+  NSArray *dictionary = FLObj->dictionary;
+  // ----------------------------------------
   
   if (varT == 1)
     {
@@ -1759,13 +1758,10 @@ static int buildSystem (const gsl_vector *v, void *p, gsl_vector *func)
   
   int nvar  = [vars count];
   const size_t n = nvar;
-  struct parameters p;
   gsl_vector *x;
   const gsl_rng_type * Y;
   gsl_rng * r;
   
-  p.a=1.0;
-  p.b=1.0;
   x = gsl_vector_alloc (n);
   
   // Random numbers generator
@@ -1803,7 +1799,7 @@ static int buildSystem (const gsl_vector *v, void *p, gsl_vector *func)
       
       f.f = &buildSystem;
       f.n = n;
-      f.params = &p;    
+      f.params = (__bridge void *)(self);
       T = gsl_multiroot_fsolver_hybrids;
       s = gsl_multiroot_fsolver_alloc (T, nvar);
       gsl_multiroot_fsolver_set (s, &f, x);
@@ -1986,10 +1982,9 @@ static int buildSystem (const gsl_vector *v, void *p, gsl_vector *func)
   NSBundle *messages;
   self = [super init];
   
-  vars = [NSMutableArray array];
-  [vars retain];
-  varsTime = [NSMutableArray array];
-  [varsTime retain];
+  vars = [NSMutableArray new];
+  varsTime = [NSMutableArray new];
+  dictionary = [NSMutableArray new];
   
   // Build the array of messages
   messages = [NSBundle mainBundle];
@@ -2016,7 +2011,7 @@ static int buildSystem (const gsl_vector *v, void *p, gsl_vector *func)
   varT = 0;
   timeDat = 0;
   
-  dictionary = [[NSArray alloc] initWithArray: [list allValues]];
+  [dictionary setArray: [list allValues]];
   enumerator = [dictionary objectEnumerator];
   
   while ((object = [enumerator nextObject]) && !error) 
