@@ -1,5 +1,5 @@
 /* 
-   Copyright (C) 2010, 2011, 2012, 2013 German A. Arias
+   Copyright (C) 2010, 2011, 2012, 2013, 2014 German A. Arias
 
    This file is part of FísicaLab application
 
@@ -26,17 +26,6 @@
 #import <gsl/gsl_rng.h>
 #import "FLKinematicsCircularMotion.h"
 
-static int varT;
-static double timeDat;
-static NSArray *dictionary;
-static NSMutableArray *vars, *varsTime;
-static NSString *timeVar;
-
-struct parameters
-{
-  double a;
-  double b;
-};
 
 static int buildSystem (const gsl_vector *v, void *p, gsl_vector *func)
 {
@@ -45,6 +34,17 @@ static int buildSystem (const gsl_vector *v, void *p, gsl_vector *func)
   double tf;
   NSMutableDictionary *object;
   NSEnumerator *enumerator;
+
+  // Get properties of FL object.
+  FLKinematicsCircularMotion *FLObj =
+    (__bridge FLKinematicsCircularMotion *)(p);
+
+  NSInteger varT = FLObj->varT;
+  NSString *timeVar = FLObj->timeVar;
+  double timeDat = FLObj->timeDat;
+  NSMutableArray *vars = FLObj->vars;
+  NSArray *dictionary = FLObj->dictionary;
+  // ----------------------------------------
   
   if (varT == 1)
     {
@@ -1866,7 +1866,6 @@ static int buildSystem (const gsl_vector *v, void *p, gsl_vector *func)
   size_t iter;
   
   const size_t n = nvar;
-  struct parameters p = {1.0, 1.0};
   
   gsl_vector *x = gsl_vector_alloc (n);
   
@@ -1917,7 +1916,7 @@ static int buildSystem (const gsl_vector *v, void *p, gsl_vector *func)
       
       f.f = &buildSystem;
       f.n = n;
-      f.params = &p;
+      f.params = (__bridge void *)(self);
       T = gsl_multiroot_fsolver_hybrids;
       s = gsl_multiroot_fsolver_alloc (T, nvar);
       gsl_multiroot_fsolver_set (s, &f, x);
@@ -2211,10 +2210,9 @@ static int buildSystem (const gsl_vector *v, void *p, gsl_vector *func)
   NSBundle *messages;
   self = [super init];
 
-  vars = [NSMutableArray array];
-  [vars retain];
-  varsTime = [NSMutableArray array];
-  [varsTime retain];
+  vars = [NSMutableArray new];
+  varsTime = [NSMutableArray new];
+  dictionary = [NSMutableArray new];
   
   // Build the messages array
   messages = [NSBundle mainBundle];
@@ -2255,7 +2253,7 @@ static int buildSystem (const gsl_vector *v, void *p, gsl_vector *func)
   varT = 0;
   timeDat = 0;
 
-  dictionary = [[NSArray alloc] initWithArray: [list allValues]];
+  [dictionary setArray: [list allValues]];
   enumerator = [dictionary objectEnumerator];
   
   while ((object = [enumerator nextObject]) && !error) 
