@@ -1,5 +1,5 @@
 /* 
-   Copyright (C) 2009, 2010, 2011, 2012, 2013 German A. Arias
+   Copyright (C) 2009, 2010, 2011, 2012, 2013, 2014 German A. Arias
 
    This file is part of FísicaLab application
 
@@ -23,6 +23,15 @@
 @interface FLStatics : FLSolverWithCells
 {
   NSArray *errors;
+
+  // For internal calculations
+  @public
+
+  NSInteger varG;
+  double gravityDat;
+  NSMutableDictionary *dictionary;
+  NSMutableArray *vars, *forceObjs, *forceTypes, *codObjects, *codOthers;
+  NSString *gravityVar;
 }
 - (void) makeEquationsForData: (NSMutableDictionary *)list;
 @end
