@@ -1,5 +1,5 @@
 /* 
-   Copyright (C) 2009, 2010, 2011, 2013 German A. Arias <german@xelalug.org>
+   Copyright (C) 2009, 2010, 2011, 2013 German A. Arias
 
    This file is part of FísicaLab application
 
@@ -22,15 +22,26 @@
 
 @interface HelpPanelController : NSObject
 {
+  // Outlets
   id text;
   id table;
+
+  // Instance variables
   NSBundle *directory;
 }
-//Metodos delegados y de datos
+
+// Delegate and source data methods
 - (void) outlineViewSelectionDidChange: (NSNotification*)aNotification;
 
-- (id) outlineView: (NSOutlineView*)outlineView child: (int)index ofItem: (id)item;
+- (id) outlineView: (NSOutlineView*)outlineView child: (NSInteger)index
+            ofItem: (id)item;
+
 - (BOOL) outlineView: (NSOutlineView*)outlineView isItemExpandable: (id)item;
-- (int) outlineView: (NSOutlineView*)outlineView numberOfChildrenOfItem: (id)item;
-- (id) outlineView: (NSOutlineView*)outlineView objectValueForTableColumn: (NSTableColumn*)tableColumn byItem: (id)item;
+
+- (NSInteger) outlineView: (NSOutlineView*)outlineView
+        numberOfChildrenOfItem: (id)item;
+
+- (id) outlineView: (NSOutlineView*)outlineView
+       objectValueForTableColumn: (NSTableColumn*)tableColumn
+       byItem: (id)item;
 @end
