@@ -1,5 +1,5 @@
 /* 
-   Copyright (C) 2009, 2010, 2011, 2012, 2013 German A. Arias
+   Copyright (C) 2009, 2010, 2011, 2012, 2013, 2014, 2015 German A. Arias
 
    This file is part of FísicaLab application
 
@@ -1779,6 +1779,65 @@
 				   @"0", nil];
       }
       break;
+      // Objetcs in 350-399 are of thermodynamics
+    case 350:
+      {
+	// Heat
+	titleList = [NSArray arrayWithObjects: @"Q", nil];
+	dataList = [NSMutableArray arrayWithObjects: @"0", nil];
+      }
+      break;
+    case 351:
+      {
+	// Work
+	titleList = [NSArray arrayWithObjects: @"W", nil];
+	dataList = [NSMutableArray arrayWithObjects: @"0", nil];
+      }
+      break;
+    case 352:
+      {
+	// Data at some state
+	titleList = [NSArray arrayWithObjects: _(@"Name"), @"p", @"t", @"d",
+			     @"V", nil];
+	dataList = [NSMutableArray arrayWithObjects: @"0", @"-", @"-", @"-",
+				   @"-", nil];
+      }
+      break;
+    case 353:
+      {
+	// Data at some state (satured)
+	titleList = [NSArray arrayWithObjects: _(@"Name"), @"p", @"t", @"d",
+			     @"V", @"x", nil];
+	dataList = [NSMutableArray arrayWithObjects: @"0", @"-", @"-", @"-",
+				   @"-", @"-", nil];
+      }
+      break;
+    case 354:
+      {
+	// Data of a flow
+	titleList = [NSArray arrayWithObjects: _(@"Name"), @"p", @"t", @"d",
+			     @"v", @"A", nil];
+	dataList = [NSMutableArray arrayWithObjects: @"0", @"-", @"-", @"-",
+				   @"-", @"-", nil];
+      }
+      break;
+    case 355:
+      {
+	// Data of a flow (satured)
+	titleList = [NSArray arrayWithObjects: _(@"Name"), @"p", @"t", @"d",
+			     @"v", @"A", @"x", nil];
+	dataList = [NSMutableArray arrayWithObjects: @"0", @"-", @"-", @"-",
+				   @"-", @"-", @"-", nil];
+      }
+      break;
+    case 356:
+      {
+	// A change
+	titleList = [NSArray arrayWithObjects: _(@"System i"), _(@"System f"),
+			     _(@"Substance"), nil];
+	dataList = [NSMutableArray arrayWithObjects: @"0", @"0", @"0", nil];
+      }
+      break;
     }
 
   if ([titleList count] != [dataList count])
@@ -1909,6 +1968,7 @@
   if (conv != nil)
     {
       factorsMenu = [[[NSMenu alloc] initWithTitle: _(@"Factors")] autorelease];
+      [factorsMenu setDelegate: self];
       
       while ((factor = [conv nextObject]))
 	{
@@ -2027,6 +2087,13 @@
   [aCell setEditable: YES];
 }
 
+
+// Delegate for contextual menu.
+- (void) menuNeedsUpdate: (NSMenu*)menu
+{
+  [chalkboard controlCursor: self];
+}
+
 - (void) dealloc
 {
   [objectsList release];
